==> nextcloud-18.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files/l10n/fr.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
    "Storage invalid" : "Support de stockage invalide",
    "Unknown error" : "Erreur inconnue ",
    "All files" : "Tous les fichiers",
    "Recent" : "Récent",
    "Favorites" : "Favoris",
    "File could not be found" : "Fichier introuvable",
    "Move or copy" : "Déplacer ou copier",
    "Download" : "Télécharger",
    "Delete" : "Supprimer",
    "Home" : "Mes fichiers",
    "Close" : "Fermer",
    "Could not create folder \"{dir}\"" : "Impossible de créer le dossier \"{dir}\"",
    "This will stop your current uploads." : "Cela va arrêter vos envois en cours.",
    "Upload cancelled." : "Envoi annulé.",
    "Processing files …" : "Fichiers en cours de traitement …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossible d'envoyer {filename} car il s'agit d'un dossier ou d'un fichier vide",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Espace libre insuffisant : vous tentez d'envoyer {size1} mais seulement {size2} sont disponibles",
    "Target folder \"{dir}\" does not exist any more" : "Le dossier cible \"{dir}\" n'existe plus",
    "Not enough free space" : "Espace disponible insuffisant",
    "An unknown error has occurred" : "Une erreur inconnue est survenue",
    "Uploading …" : "Envoi en cours ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} sur {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "L'envoi de cet élément n'est pas supporté",
    "Target folder does not exist any more" : "Le dossier cible n'existe plus",
    "Error when assembling chunks, status code {status}" : "Erreur lors de l'assemblage des blocs, code d'état {status}",
    "Actions" : "Actions",
    "Rename" : "Renommer",
    "Copy" : "Copier",
    "Choose target folder" : "Sélectionner le dossier cible",
    "Open" : "Ouvrir",
    "Delete file" : "Supprimer le fichier",
    "Delete folder" : "Supprimer le dossier",
    "Disconnect storage" : "Déconnecter ce support de stockage",
    "Unshare" : "Ne plus partager",
    "Could not load info for file \"{file}\"" : "Impossible de charger les informations du fichier \"{file}\"",
    "Files" : "Fichiers",
    "Details" : "Détails",
    "Select" : "Sélectionner",
    "Pending" : "En attente",
    "Unable to determine date" : "Impossible de déterminer la date",
    "This operation is forbidden" : "Cette opération est interdite",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ce dossier n'est pas disponible, consultez les logs ou contactez votre administrateur",
    "Could not move \"{file}\", target exists" : "Impossible de déplacer \"{file}\", la cible existe",
    "Could not move \"{file}\"" : "Impossible de déplacer \"{file}\"",
    "copy" : "copie",
    "Could not copy \"{file}\", target exists" : "Impossible de copier \"{file}\", la cible existe",
    "Could not copy \"{file}\"" : "Impossible de copier \"{file}\"",
    "Copied {origin} inside {destination}" : "{origin} copié dans {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} et {nbfiles} autres fichiers copiés dans {destination}",
    "{newName} already exists" : "{newName} existe déjà",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossible de renommer \"{fileName}\", il n'existe plus",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{targetName}\" est déjà utilisé dans le dossier \"{dir}\". Merci de choisir un nom différent.",
    "Could not rename \"{fileName}\"" : "Impossible de renommer \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossible de créer le fichier \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossible de créer le fichier \"{file}\" car il existe déjà",
    "Could not create folder \"{dir}\" because it already exists" : "Impossible de créer le dossier \"{dir}\" car il existe déjà",
    "Error deleting file \"{fileName}\"." : "Erreur à la suppression du fichier \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Aucun résultat dans d'autres dossiers pour {tag}{filter}{endtag}",
    "Name" : "Nom",
    "Size" : "Taille",
    "Modified" : "Modifié",
    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers"],
    "_%n file_::_%n files_" : ["%n fichier","%n fichiers"],
    "{dirs} and {files}" : "{dirs} et {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclus %n masqué","dont %n masqués"],
    "You don’t have permission to upload or create files here" : "Vous n'avez pas la permission d'envoyer ou de créer des fichiers ici",
    "_Uploading %n file_::_Uploading %n files_" : ["Téléversement de %n fichier","Téléversement de %n fichiers"],
    "New" : "Nouveau",
    "Select file range" : "Sélectionner une plage de fichiers",
    "{used} of {quota} used" : "{used} de {quota} utilisés",
    "{used} used" : "{used} utilisés",
    "\"{name}\" is an invalid file name." : "\"{name}\" n'est pas un nom de fichier valide.",
    "File name cannot be empty." : "Le nom de fichier ne peut pas être vide.",
    "\"/\" is not allowed inside a file name." : "\"/\" n'est pas autorisé dans un nom de fichier.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" n'est pas un type de fichier autorisé",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'espace de stockage de {owner} est plein. Les fichiers ne peuvent plus être mis à jour ni synchronisés !",
    "Your storage is full, files can not be updated or synced anymore!" : "Votre espace de stockage est plein. Les fichiers ne peuvent plus être mis à jour ni synchronisés !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "L'espace de stockage de {owner} est presque plein ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Votre espace de stockage est presque plein ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["correspond à '{filter}'","correspondent à '{filter}'"],
    "View in folder" : "Afficher dans le dossier",
    "Copied!" : "Copié !",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copier le Lien direct (fonctionne uniquement pour les utilisateurs autorisés à accéder à ce fichier ou à ce dossier)",
    "Path" : "Chemin",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octets"],
    "Favorited" : "Marqué comme favori",
    "Favorite" : "Favoris",
    "You can only favorite a single file or folder at a time" : "Vous ne pouvez ajouter qu'un seul favori de dossier ou de fichier à la fois.",
    "New folder" : "Nouveau dossier",
    "Upload file" : "Envoyer un fichier",
    "Not favorited" : "Non marqué comme favori",
    "Remove from favorites" : "Retirer des favoris",
    "Add to favorites" : "Ajouter aux favoris",
    "An error occurred while trying to update the tags" : "Une erreur est survenue lors de la mise à jour des étiquettes",
    "Added to favorites" : "Ajouté aux favoris",
    "Removed from favorites" : "Retiré des favoris",
    "You added {file} to your favorites" : "Vous avez ajouté {file} à vos favoris",
    "You removed {file} from your favorites" : "Vous avez retiré {file} de vos favoris",
    "File changes" : "Modifications de fichiers",
    "Created by {user}" : "Créé par {user}",
    "Changed by {user}" : "Modifié par {user}",
    "Deleted by {user}" : "Supprimé par {user}",
    "Restored by {user}" : "Restauré par {user}",
    "Renamed by {user}" : "Renommé par {user}",
    "Moved by {user}" : "Déplacé par {user}",
    "\"remote user\"" : "\"utilisateur distant\"",
    "You created {file}" : "Vous avez créé {file}",
    "You created an encrypted file in {file}" : "Vous avez créé un fichier chiffré dans {file}",
    "{user} created {file}" : "{user} a créé {file}",
    "{user} created an encrypted file in {file}" : "{user} a créé un fichier chiffré dans {file}",
    "{file} was created in a public folder" : "{file} a été créé dans un dossier public",
    "You changed {file}" : "Vous avez modifié {file}",
    "You changed an encrypted file in {file}" : "Vous avez modifié un fichier chiffré dans {file}",
    "{user} changed {file}" : "{user} a modifié {file}",
    "{user} changed an encrypted file in {file}" : "{user} a modifié un fichier chiffré dans {file}",
    "You deleted {file}" : "Vous avez supprimé {file}",
    "You deleted an encrypted file in {file}" : "Vous avez supprimé un fichier chiffré dans {file}",
    "{user} deleted {file}" : "{user} a supprimé {file}",
    "{user} deleted an encrypted file in {file}" : "{user} a supprimé un fichier chiffré dans {file}",
    "You restored {file}" : "Vous avez restauré {file}",
    "{user} restored {file}" : "{user} a restauré {file}",
    "You renamed {oldfile} to {newfile}" : "Vous avez renommé {oldfile} en {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} a renommé {oldfile} en {newfile}",
    "You moved {oldfile} to {newfile}" : "Vous avez déplacé {oldfile} dans {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} a déplacé {oldfile} dans {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un fichier a été ajouté ou retiré de vos <strong>favoris</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un fichier ou dossier a été <strong>modifié</strong> ou <strong>renommé</strong>",
    "A new file or folder has been <strong>created</strong>" : "Un nouveau fichier ou répertoire a été <strong>créé</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un fichier ou un dossier a été <strong>supprimé</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limiter les notifications qui concernent les créations et les modifications à vos <strong>fichiers favoris</strong> <em>(Flux uniquement)</em>",
    "A file or folder has been <strong>restored</strong>" : "Un fichier ou un dossier a été <strong>restauré</strong>",
    "Unlimited" : "Illimité",
    "Upload (max. %s)" : "Envoi (max. %s)",
    "Accept" : "Accepter",
    "Reject" : "Refuser",
    "Incoming ownership transfer from {user}" : "Transfert de propriété de la part de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Voulez-vous accepter {path} ?\n\nN. B. : L'opération de transfert après acceptation peut prendre jusqu'à 1 heure.",
    "Ownership transfer failed" : "Le transfert de propriétaire a échoué",
    "Your ownership transfer of {path} to {user} failed." : "Votre transfert de propriété de {path} à {user} a échoué.",
    "The ownership transfer of {path} from {user} failed." : "Le transfert de propriété de {path} de {user} a échoué.",
    "Ownership transfer done" : "Transfert de propriétaire terminé",
    "Your ownership transfer of {path} to {user} has completed." : "Votre transfert de propriété de {path} à {user} est terminé.",
    "The ownership transfer of {path} from {user} has completed." : "Le transfert de propriété de {path} de {user} est terminé.",
    "File Management" : "Gestion de fichier",
    "Transfer ownership of a file or folder" : "Transférer la propriété d'un fichier ou d'un dossier",
    "Choose file or folder to transfer" : "Sélectionnez un fichier ou un dossier à transférer",
    "Change" : "Modifier",
    "New owner" : "Nouveau propriétaire",
    "Search users" : "Rechercher des utilisateurs",
    "Choose a file or folder to transfer" : "Sélectionnez un fichier ou un dossier à transférer",
    "Transfer" : "Transférer",
    "Transfer {path} to {userid}" : "Transférer {path} à {userid}",
    "Invalid path selected" : "Chemin sélectionné non valide",
    "Ownership transfer request sent" : "Requête de transfert de propriété envoyée",
    "Tags" : "Étiquettes",
    "Error while loading the file data" : "Erreur lors du chargement du fichier de données",
    "Unable to change the favourite state of the file" : "Impossible de modifier l'état favori du fichier",
    "%s used" : "%s utilisés",
    "%s%% of %s used" : "%s%% de %s utilisé",
    "%1$s of %2$s used" : "%1$s utilisés sur %2$s",
    "Settings" : "Paramètres",
    "Show hidden files" : "Afficher les fichiers masqués",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Utilisez cette adresse pour <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">accéder à vos fichiers par WebDAV</a>",
    "Toggle grid view" : "Activer/Désactiver l'affichage mosaïque",
    "No files in here" : "Aucun fichier",
    "Upload some content or sync with your devices!" : "Déposez du contenu ou synchronisez vos appareils !",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Select all" : "Tout sélectionner",
    "Upload too large" : "Téléversement trop volumineux",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Les fichiers que vous essayez d'envoyer dépassent la taille maximale d'envoi permise par ce serveur.",
    "No favorites yet" : "Aucun favori pour l'instant",
    "Files and folders you mark as favorite will show up here" : "Les fichiers et dossiers ajoutés à vos favoris apparaîtront ici",
    "Deleted files" : "Fichiers supprimés",
    "Shares" : "Partages",
    "Shared with others" : "Partagés avec d'autres",
    "Shared with you" : "Partagés avec vous",
    "Shared by link" : "Partagés par lien",
    "Deleted shares" : "Partages supprimés",
    "Pending shares" : "Partages en attente",
    "Text file" : "Fichier texte",
    "New text file.txt" : "Nouveau fichier texte.txt",
    "%s of %s used" : "%s de %s utilisé",
    "%1$s%% of %2$s used" : "%1$s%% de %2$s utilisés"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-20.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files/l10n/fr.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
    "Storage invalid" : "Support de stockage invalide",
    "Unknown error" : "Erreur inconnue ",
    "File could not be found" : "Fichier introuvable",
    "Move or copy" : "Déplacer ou copier",
    "Download" : "Télécharger",
    "Delete" : "Supprimer",
    "Home" : "Accueil",
    "Close" : "Fermer",
    "Favorites" : "Favoris",
    "Could not create folder \"{dir}\"" : "Impossible de créer le dossier \"{dir}\"",
    "This will stop your current uploads." : "Cela va arrêter vos envois en cours.",
    "Upload cancelled." : "Téléversement annulé.",
    "Processing files …" : "Fichiers en cours de traitement …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossible d'envoyer {filename} car il s'agit d'un dossier ou d'un fichier vide",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Espace libre insuffisant : vous tentez d'envoyer {size1} mais seulement {size2} sont disponibles",
    "Target folder \"{dir}\" does not exist any more" : "Le dossier cible \"{dir}\" n'existe plus",
    "Not enough free space" : "Espace disponible insuffisant",
    "An unknown error has occurred" : "Une erreur inconnue est survenue",
    "Uploading …" : "Envoi en cours ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} sur {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "L'envoi de cet élément n'est pas supporté",
    "Target folder does not exist any more" : "Le dossier cible n'existe plus",
    "Operation is blocked by access control" : "L'opération est bloquée par le contrôle d'accès",
    "Error when assembling chunks, status code {status}" : "Erreur lors de l'assemblage des blocs, code d'état {status}",
    "Actions" : "Actions",
    "Rename" : "Renommer",
    "Copy" : "Copier",
    "Choose target folder" : "Sélectionner le dossier cible",
    "Open" : "Ouvrir",
    "Delete file" : "Supprimer le fichier",
    "Delete folder" : "Supprimer le dossier",
    "Disconnect storage" : "Déconnecter ce support de stockage",
    "Leave this share" : "Quitter ce partage",
    "Could not load info for file \"{file}\"" : "Impossible de charger les informations du fichier \"{file}\"",
    "Files" : "Fichiers",
    "Details" : "Détails",
    "Select" : "Sélectionner",
    "Pending" : "En attente",
    "Unable to determine date" : "Impossible de déterminer la date",
    "This operation is forbidden" : "Cette opération est interdite",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ce répertoire est indisponnible, merci de consulter les journaux ou de contacter votre administrateur",
    "Could not move \"{file}\", target exists" : "Impossible de déplacer \"{file}\", la cible existe",
    "Could not move \"{file}\"" : "Impossible de déplacer \"{file}\"",
    "copy" : "copie",
    "Could not copy \"{file}\", target exists" : "Impossible de copier \"{file}\", la cible existe",
    "Could not copy \"{file}\"" : "Impossible de copier \"{file}\"",
    "Copied {origin} inside {destination}" : "{origin} copié dans {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} et {nbfiles} autres fichiers copiés dans {destination}",
    "{newName} already exists" : "{newName} existe déjà",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossible de renommer \"{fileName}\" car il n'existe plus",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{targetName}\" est déjà utilisé dans le dossier \"{dir}\". Merci de choisir un nom différent.",
    "Could not rename \"{fileName}\"" : "Impossible de renommer \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossible de créer le fichier \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossible de créer le fichier \"{file}\" car il existe déjà",
    "Could not create folder \"{dir}\" because it already exists" : "Impossible de créer le dossier \"{dir}\" car il existe déjà",
    "Could not fetch file details \"{file}\"" : "Impossible de récupérer les détails du fichier \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Erreur à la suppression du fichier \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Aucun résultat dans d'autres dossiers pour {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Entrez plus de deux caractères pour effectuer une recherche dans d'autres dossiers",
    "Name" : "Nom",
    "Size" : "Taille",
    "Modified" : "Modifié",
    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers"],
    "_%n file_::_%n files_" : ["%n fichier","%n fichiers"],
    "{dirs} and {files}" : "{dirs} et {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclus %n masqué","dont %n masqués"],
    "You don’t have permission to upload or create files here" : "Vous n'avez pas la permission d'envoyer ou de créer des fichiers ici",
    "_Uploading %n file_::_Uploading %n files_" : ["Téléversement de %n fichier","Téléversement de %n fichiers"],
    "New" : "Nouveau",
    "Select file range" : "Sélectionner une plage de fichiers",
    "{used} of {quota} used" : "{used} utilisés sur {quota}",
    "{used} used" : "{used} utilisés",
    "\"{name}\" is an invalid file name." : "\"{name}\" n'est pas un nom de fichier valide.",
    "File name cannot be empty." : "Le nom de fichier ne peut pas être vide.",
    "\"/\" is not allowed inside a file name." : "\"/\" n'est pas autorisé dans un nom de fichier.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" n'est pas un type de fichier autorisé",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'espace de stockage de {owner} est plein. Les fichiers ne peuvent plus être mis à jour ni synchronisés !",
    "External storage \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "L'espace de stockage externe \"{mountPoint}\" est plein, les fichiers ne peuvent plus être mis à jour ni synchronisés !",
    "Your storage is full, files can not be updated or synced anymore!" : "Votre espace de stockage est plein. Les fichiers ne peuvent plus être mis à jour ni synchronisés !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "L'espace de stockage de {owner} est presque plein ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'espace de stockage externe \"{mountPoint}\" est presque plein ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Votre espace de stockage est presque plein ({usedSpacePercent}%).",
    "_matches '{filter}'_::_match '{filter}'_" : ["correspond à '{filter}'","correspondent à '{filter}'"],
    "View in folder" : "Afficher dans le dossier",
    "Copied!" : "Copié !",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copier le Lien direct (fonctionne uniquement pour les utilisateurs autorisés à accéder à ce fichier ou à ce dossier)",
    "Path" : "Chemin",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octets"],
    "Favorited" : "Marqué comme favori",
    "Favorite" : "Favoris",
    "You can only favorite a single file or folder at a time" : "Vous ne pouvez ajouter qu'un seul favori de dossier ou de fichier à la fois.",
    "New folder" : "Nouveau dossier",
    "Upload file" : "Envoyer un fichier",
    "Recent" : "Récent",
    "Not favorited" : "Non marqué comme favori",
    "Remove from favorites" : "Retirer des favoris",
    "Add to favorites" : "Ajouter aux favoris",
    "An error occurred while trying to update the tags" : "Une erreur est survenue lors de la mise à jour des étiquettes",
    "Added to favorites" : "Ajouté aux favoris",
    "Removed from favorites" : "Retiré des favoris",
    "You added {file} to your favorites" : "Vous avez ajouté {file} à vos favoris",
    "You removed {file} from your favorites" : "Vous avez retiré {file} de vos favoris",
    "File changes" : "Modifications de fichiers",
    "Created by {user}" : "Créé par {user}",
    "Changed by {user}" : "Modifié par {user}",
    "Deleted by {user}" : "Supprimé par {user}",
    "Restored by {user}" : "Restauré par {user}",
    "Renamed by {user}" : "Renommé par {user}",
    "Moved by {user}" : "Déplacé par {user}",
    "\"remote user\"" : "\"utilisateur distant\"",
    "You created {file}" : "Vous avez créé {file}",
    "You created an encrypted file in {file}" : "Vous avez créé un fichier chiffré dans {file}",
    "{user} created {file}" : "{user} a créé {file}",
    "{user} created an encrypted file in {file}" : "{user} a créé un fichier chiffré dans {file}",
    "{file} was created in a public folder" : "{file} a été créé dans un dossier public",
    "You changed {file}" : "Vous avez modifié {file}",
    "You changed an encrypted file in {file}" : "Vous avez modifié un fichier chiffré dans {file}",
    "{user} changed {file}" : "{user} a modifié {file}",
    "{user} changed an encrypted file in {file}" : "{user} a modifié un fichier chiffré dans {file}",
    "You deleted {file}" : "Vous avez supprimé {file}",
    "You deleted an encrypted file in {file}" : "Vous avez supprimé un fichier chiffré dans {file}",
    "{user} deleted {file}" : "{user} a supprimé {file}",
    "{user} deleted an encrypted file in {file}" : "{user} a supprimé un fichier chiffré dans {file}",
    "You restored {file}" : "Vous avez restauré {file}",
    "{user} restored {file}" : "{user} a restauré {file}",
    "You renamed {oldfile} to {newfile}" : "Vous avez renommé {oldfile} en {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} a renommé {oldfile} en {newfile}",
    "You moved {oldfile} to {newfile}" : "Vous avez déplacé {oldfile} dans {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} a déplacé {oldfile} dans {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un fichier a été ajouté ou retiré de vos <strong>favoris</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un fichier ou un répertoire a été <strong>modifié</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Un fichier ou un dossier favori a été <strong>modifié </strong>",
    "All files" : "Tous les fichiers",
    "Unlimited" : "Illimité",
    "Upload (max. %s)" : "Envoi (max. %s)",
    "Accept" : "Accepter",
    "Reject" : "Refuser",
    "Incoming ownership transfer from {user}" : "Transfert de propriété de la part de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Voulez-vous accepter {path} ?\n\nN. B. : L'opération de transfert après acceptation peut prendre jusqu'à 1 heure.",
    "Ownership transfer failed" : "Le transfert de propriétaire a échoué",
    "Your ownership transfer of {path} to {user} failed." : "Votre transfert de propriété de {path} à {user} a échoué.",
    "The ownership transfer of {path} from {user} failed." : "Le transfert de propriété de {path} de {user} a échoué.",
    "Ownership transfer done" : "Transfert de propriétaire terminé",
    "Your ownership transfer of {path} to {user} has completed." : "Votre transfert de propriété de {path} à {user} est terminé.",
    "The ownership transfer of {path} from {user} has completed." : "Le transfert de propriété de {path} de {user} est terminé.",
    "in %s" : "dans %s",
    "File Management" : "Gestion de fichier",
    "Transfer ownership of a file or folder" : "Transférer la propriété d'un fichier ou d'un dossier",
    "Choose file or folder to transfer" : "Sélectionnez un fichier ou un dossier à transférer",
    "Change" : "Modifier",
    "New owner" : "Nouveau propriétaire",
    "Search users" : "Rechercher des utilisateurs",
    "Choose a file or folder to transfer" : "Sélectionnez un fichier ou un dossier à transférer",
    "Transfer" : "Transférer",
    "Transfer {path} to {userid}" : "Transférer {path} à {userid}",
    "Invalid path selected" : "Chemin sélectionné non valide",
    "Ownership transfer request sent" : "Requête de transfert de propriété envoyée",
    "Cannot transfer ownership of a file or folder you don't own" : "Impossible de transférer la propriété d’un fichier ou d’un dossier dont vous n'êtes pas le propriétaire",
    "Tags" : "Étiquettes",
    "Unable to change the favourite state of the file" : "Impossible de modifier l'état favori du fichier",
    "Error while loading the file data" : "Erreur lors du chargement du fichier de données",
    "%s used" : "%s utilisés",
    "%s%% of %s used" : "%s%% de %s utilisé",
    "%1$s of %2$s used" : "%1$s utilisés sur %2$s",
    "Settings" : "Paramètres",
    "Show hidden files" : "Afficher les fichiers masqués",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Utilisez cette adresse pour accéder à vos fichiers via WebDAV",
    "Toggle grid view" : "Activer/Désactiver l'affichage mosaïque",
    "No files in here" : "Aucun fichier",
    "Upload some content or sync with your devices!" : "Déposez du contenu ou synchronisez vos appareils !",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Select all" : "Tout sélectionner",
    "Upload too large" : "Téléversement trop volumineux",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Les fichiers que vous essayez d'envoyer dépassent la taille maximale d'envoi permise par ce serveur.",
    "No favorites yet" : "Aucun favori pour l'instant",
    "Files and folders you mark as favorite will show up here" : "Les fichiers et dossiers ajoutés à vos favoris apparaîtront ici",
    "Deleted files" : "Fichiers supprimés",
    "Shares" : "Partages",
    "Shared with others" : "Partagés avec d'autres",
    "Shared with you" : "Partagés avec vous",
    "Shared by link" : "Partagés par lien",
    "Deleted shares" : "Partages supprimés",
    "Pending shares" : "Partages en attente",
    "Text file" : "Fichier texte",
    "New text file.txt" : "Nouveau fichier texte.txt",
    "Unshare" : "Ne plus partager",
    "This group folder is full, files can not be updated or synced anymore!" : "Le dossier de groupe est plein, les fichiers ne peuvent plus être mis à jour ou synchronisés !",
    "This external storage is full, files can not be updated or synced anymore!" : "Cet espace de stockage externe est plein, les fichiers ne peuvent plus être mis à jour ni synchronisés !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "L'espace de stockage de {owner} est presque plein ({usedSpacePercent}%)",
    "This group folder is almost full ({usedSpacePercent}%)" : "Ce dossier de groupe est presque plein ({usedSpacePercent}%).",
    "This external storage is almost full ({usedSpacePercent}%)" : "Cet espace de stockage externe est presque plein ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Votre espace de stockage est presque plein ({usedSpacePercent}%)",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un fichier ou dossier a été <strong>modifié</strong> ou <strong>renommé</strong>",
    "A new file or folder has been <strong>created</strong>" : "Un nouveau fichier ou répertoire a été <strong>créé</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un fichier ou un dossier a été <strong>supprimé</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limiter les notifications qui concernent les créations et les modifications à vos <strong>fichiers favoris</strong> <em>(Flux uniquement)</em>",
    "A file or folder has been <strong>restored</strong>" : "Un fichier ou un dossier a été <strong>restauré</strong>",
    "Cannot transfter ownership of a file or folder you don't own" : "Impossible de transférer la propriété d’un fichier ou d’un dossier que vous ne possédez pas",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Utilisez cette adresse pour <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">accéder à vos fichiers par WebDAV</a>"
},
"nplurals=2; plural=(n > 1);");
